| Type: | Package |
| Title: | Empirical Extrapolation of Time Feature Patterns |
| Version: | 2.0.0 |
| Description: | Empirically extrapolates recurring patterns in numeric and categorical time-feature sequences. Candidate windows are selected by similarity, validated with rolling-origin evaluation, and summarized as forecast distributions. The runtime package uses only base R. |
| License: | GPL-3 |
| Encoding: | UTF-8 |
| LazyData: | true |
| RoxygenNote: | 7.3.3 |
| Depends: | R (≥ 4.1) |
| Suggests: | knitr, rmarkdown, testthat (≥ 3.0.0) |
| VignetteBuilder: | knitr |
| Config/testthat/edition: | 3 |
| NeedsCompilation: | no |
| Packaged: | 2026-09-07 20:12:12 UTC; gianc |
| Author: | Giancarlo Vercellino [aut, cre] |
| Maintainer: | Giancarlo Vercellino <giancarlo.vercellino@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-07 20:50:02 UTC |
Compatibility wrapper for empirical extrapolation
Description
Calls 'naive_fit()' using the v1-compatible argument list.
Empirical Extrapolation of Time Feature Pattern
Usage
naive(
df,
seq_len = NULL,
ci = 0.8,
smoother = FALSE,
cover = NULL,
stride = NULL,
method = NULL,
location = NULL,
n_windows = 10,
n_samp = 30,
dates = NULL,
error_scale = "naive",
error_benchmark = "naive",
seed = 42
)
Arguments
df |
Numeric or categorical data frame. |
seq_len |
Forecast horizon. |
ci |
Prediction interval coverage. |
smoother |
Compatibility argument. |
cover |
Similarity-window coverage. |
stride |
Window stride. |
method |
Distance method. |
location |
Location statistic. |
n_windows |
Number of validation windows. |
n_samp |
Number of candidate configurations. |
dates |
Optional dates. |
error_scale |
Compatibility metric scale. |
error_benchmark |
Compatibility metric benchmark. |
seed |
Random seed. |
Author(s)
Maintainer: Giancarlo Vercellino giancarlo.vercellino@gmail.com
Empirical extrapolation of time-feature patterns
Description
Empirical extrapolation of time-feature patterns
Usage
naive_fit(
df,
seq_len = NULL,
ci = 0.8,
n_windows = 10,
n_samp = 30,
seed = 42,
...
)
Arguments
df |
Numeric or categorical data frame. |
seq_len |
Forecast horizon. |
ci |
Prediction interval coverage. |
n_windows |
Number of validation windows. |
n_samp |
Number of candidate configurations. |
seed |
Random seed. |
... |
Compatibility arguments: 'cover', 'stride', 'method', 'location', 'dates', 'error_scale', 'error_benchmark', and 'smoother'. |
Value
An object of class 'naive_forecast'.
Generate an empirical forecast
Description
Generate an empirical forecast
Usage
naive_forecast(
df,
horizon,
ci = 0.8,
cover = 0.5,
stride = 1,
method = "euclidean",
location = "median",
dates = NULL,
seed = 42
)
Arguments
df |
Numeric or categorical data frame. |
horizon |
Forecast horizon. |
ci |
Prediction interval coverage. |
cover |
Similarity-window coverage. |
stride |
Window stride. |
method |
Distance method. |
location |
Location statistic. |
dates |
Optional dates. |
seed |
Random seed. |
Calculate basic forecast errors
Description
Calculate basic forecast errors
Usage
naive_metrics(actual, predicted)
Arguments
actual |
Actual values. |
predicted |
Predicted values. |
time features example: IBM, AAPL, AMZN, GOOGL and MSFT Close Prices
Description
A data frame with with daily with daily prices for some Big Tech Companies since March 2017.
Usage
time_features
Format
A data frame with 6 columns and 1336 rows.
finance.yahoo.com